#
# spec file for package cddlib
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cddlib
%define lname   libcdd0
Version:        0.94m
Release:        1.14
Summary:        Library for finding vertices of convex polytopes
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.inf.ethz.ch/personal/fukudak/cdd_home/

Source:         https://github.com/cddlib/cddlib/releases/download/%version/%name-%version.tar.gz
BuildRequires:  fdupes
BuildRequires:  gmp-devel >= 3

%description
cddlib is a C implementation of the Double Description Method of
Motzkin et al. for generating all vertices (i.e. extreme points) and
extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities.

%package -n %lname
Summary:        Library for finding vertices of convex polytopes
Group:          System/Libraries

%description -n %lname
cddlib is a C implementation of the Double Description Method of
Motzkin et al. for generating all vertices (i.e. extreme points) and
extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities.

%package devel
Summary:        Header files for cddlib
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       gmp-devel

%description devel
cddlib is a C implementation of the Double Description Method of
Motzkin et al. for generating all vertices (i.e. extreme points) and
extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities.

This package contains the headers for the C library.

%package doc
Summary:        Documentation for the cddlib API
Group:          Documentation/Other
BuildArch:      noarch

%description doc
cddlib is an implementation of the Double Description Method of
Motzkin et al.

This package contains the documentation to cddlib.

%package tools
Summary:        Programs for vertex generation using Double Description Method
Group:          Productivity/Scientific/Math
Provides:       cddlib-devel:/usr/bin/scdd
Conflicts:      cddlib-devel < 0.94l

%description tools
cddlib is a C implementation of the Double Description Method of
Motzkin et al. for generating all vertices (i.e. extreme points) and
extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities.

This package contains the command-line utilities of cddlib.

%prep
%autosetup -p1

%build
%configure --enable-shared --disable-static --docdir="%_docdir/%name"
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libcdd*.so.*

%files devel
%_libdir/libcdd*.so
%_includedir/*
%_libdir/pkgconfig/*.pc

%files doc
%_docdir/%name/

%files tools
%_bindir/*
%license COPYING

%changelog
* Tue Dec  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.94m
  * Fix and error, where a non-redundant linearity could be
    considered redundant.
  * Fix an optimization error in ViaShooting code so that the linear
    programs are now much smaller.
  * Fixed memory leaks in the redundancy code.
* Sun Sep 20 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.94l
  * Merged 0001-build-extend-extern-C-block-in-header-files.patch
- Split command-line programs to new package cddlib-tools.
* Sat Sep 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.94k
  * Header files are now installed to PREFIX/include/cddlib to
    avoid clashes with other libraries.
  * pkg-config cddlib.pc file added.
- Add 0001-build-extend-extern-C-block-in-header-files.patch
* Sat Oct 20 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.94j
  * Introduced cddexec as a replacement of cdd_both_reps that many
    distributions packaged.
- Remove cddlib-flags.diff, cddlib-automake.diff
* Mon Apr 30 2018 jengelh@inai.de
- Update to new upstream release 0.94i
  * The missing definition of dd_set_d function (in the
  - DGMPRATIONAL case) was added.
* Mon Dec 25 2017 jengelh@inai.de
- Switch include directory to /usr/include/cdd as that seems to be
  expected by downstream programs (like gfan).
* Mon Feb 20 2017 jengelh@inai.de
- Update homepage URL
* Mon Jul  4 2016 jengelh@inai.de
- Update cddlib-automake.diff to add -no-undefined
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 0.94h
  * One unspecified minor bugfix
* Sat Oct 11 2014 jengelh@inai.de
- Use source URLs
* Tue Aug 21 2012 jengelh@inai.de
- Restore and rediff patches
* Tue Aug 21 2012 dmitry@roshchin.org
- Update to version 0.94g
  * fixed memory leaks in cddlib.c and cddlp.c
  * integrated patches for making the library
    shared and more compatible for C++ compilers
